@@ -8,13 +8,13 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
     let impl_name = impl_type.ident.to_string();
     let interfaces = implements.interfaces();
 
-    let mut tokens = TokenStream::with_capacity();
+    let mut tokens = TokenStream::new();
     let mut vtable_idents = vec![];
     let mut vtable_ordinals = vec![];
-    let mut vtable_ctors = TokenStream::with_capacity();
-    let mut shims = TokenStream::with_capacity();
-    let mut queries = TokenStream::with_capacity();
-    let mut query_constants = TokenStream::with_capacity();
+    let mut vtable_ctors = TokenStream::new();
+    let mut shims = TokenStream::new();
+    let mut queries = TokenStream::new();
+    let mut query_constants = TokenStream::new();
     let gen = gen::Gen::absolute();
 
     let mut generics = BTreeSet::new();
@@ -109,7 +109,7 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
             const #interface_constant: ::windows::core::GUID = <#interface_ident as ::windows::core::Interface>::IID;
         });
 
-        for method in base_interfaces.iter().rev().chain(core::iter::once(def)).map(|def| def.methods()).flatten() {
+        for method in base_interfaces.iter().rev().chain(core::iter::once(def)).flat_map(|def| def.methods()) {
             let method_ident = gen::to_ident(&method.rust_name());
 
             abi_count += 1;
@@ -168,7 +168,7 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
                 }
                 impl<#constraints> ::windows::core::ToImpl<#interface_ident> for #impl_ident {
                     unsafe fn to_impl(interface: &#interface_ident) -> &mut Self {
-                        let this: ::windows::core::RawPtr = core::mem::transmute_copy(interface);
+                        let this: ::windows::core::RawPtr = ::core::mem::transmute_copy(interface);
                         let this = (this as *mut ::windows::core::RawPtr).sub(2 + #interface_count) as *mut #box_ident::<#(#generics,)*>;
                         &mut (*this).implementation
                     }
@@ -176,10 +176,10 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
             });
         }
 
-        let mut phantoms = TokenStream::with_capacity();
+        let mut phantoms = TokenStream::new();
 
         for _ in 0..def.generic_params().count() {
-            phantoms.combine(&quote! { core::marker::PhantomData, })
+            phantoms.combine(&quote! { ::core::marker::PhantomData, })
         }
 
         vtable_ctors.combine(&quote! {
@@ -240,7 +240,7 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
             }
         }
         impl <#constraints> ::windows::core::Compose for #impl_ident {
-            unsafe fn compose<'a>(implementation: Self) -> (::windows::core::IInspectable, &'a mut core::option::Option<::windows::core::IInspectable>) {
+            unsafe fn compose<'a>(implementation: Self) -> (::windows::core::IInspectable, &'a mut ::core::option::Option<::windows::core::IInspectable>) {
                 let inspectable: ::windows::core::IInspectable = implementation.into();
                 let this = (&inspectable as *const _ as *mut ::windows::core::RawPtr).sub(1) as *mut #box_ident::<#(#generics,)*>;
                 (inspectable, &mut (*this).base)
@@ -249,7 +249,7 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
         #[repr(C)]
         struct #box_ident<#(#generics,)*> where #constraints {
             base: ::core::option::Option<::windows::core::IInspectable>,
-            identity_vtable: *const ::windows::core::IInspectable_abi,
+            identity_vtable: *const ::windows::core::IInspectableVtbl,
             vtables: (#(*const #vtable_idents,)*),
             implementation: #impl_ident,
             count: ::windows::core::WeakRefCount,
@@ -258,7 +258,7 @@ pub fn gen(attribute: proc_macro::TokenStream, original_type: proc_macro::TokenS
             const VTABLES: (#(#vtable_idents,)*) = (
                 #vtable_ctors
             );
-            const IDENTITY_VTABLE: ::windows::core::IInspectable_abi = ::windows::core::IInspectable_abi(
+            const IDENTITY_VTABLE: ::windows::core::IInspectableVtbl = ::windows::core::IInspectableVtbl(
                 Self::identity_query_interface,
                 Self::identity_add_ref,
                 Self::identity_release,
